Learn R Programming

InterVA5 (version 1.1.3)

print.interVA5_summary: Print method for summary of the results obtained from InterVA5 algorithm

Description

This function prints the summary message of the fitted results.

Usage

# S3 method for interVA5_summary
print(x, ...)

Arguments

x

summary of InterVA5 results

...

not used